@@ -38,7 +38,7 @@ def safeMask( mask ):
     #don't use re.UNICODE because safeFileName don't permit to use unicode char.
     #we must work whit the same char set    
     mask = re.sub( "(;|`|$\(\s)+" , '_' , mask )
-    mask = re.sub( "^.*[\\\:/]", "" ,  mask  )
+    mask = re.sub( "^.*[\\\]", "" ,  mask  )
     return mask
 
 
@@ -379,6 +379,9 @@ class MultipleChoiceDataType( StringDataType ):
         return mt
     
     def validate( self, param ):
+        #values are stored as string in evaluator
+        #the string is computed by service.setValue()
+        #the string is return by getValue and used as is in ComandBuilder 
         userValues = param.getValue() #it's a string
         sep = param.getSeparator()
         if sep == '':
@@ -395,6 +398,9 @@ class MultipleChoiceDataType( StringDataType ):
                 raise UserValueError( parameter = param , msg = msg )
         return True
 
+
+    
+
 class AbstractFileDataType(DataType):
     """
     AbstractFileDataType is an abstract class that centralizes the
@@ -597,7 +603,10 @@ class AbstractFileDataType(DataType):
             else:
                 return os.path.exists( param.getValue() )
 
-    
+
+
+
+
 class AbstractTextDataType( AbstractFileDataType ):
 
     def head( self , data ):
@@ -712,6 +721,8 @@ class AbstractTextDataType( AbstractFileDataType ):
         size = os.path.getsize( abs_DestFileName )
         return os.path.basename( abs_DestFileName ) , size
 
+
+
 class TextDataType( AbstractTextDataType ):
     # this trick is to avoid that SequenceDataType is a subclass of TextDataType
     pass
