@@ -2,7 +2,7 @@
 #                                                                                      #
 #   Author: Bertrand Neron,                                                            #
 #   Organization:'Biological Software and Databases' Group, Institut Pasteur, Paris.   #  
-#   Distributed under GPLv2 Licence. Please refer to the COPYING.LIB document.        #
+#   Distributed under LGPLv2 Licence. Please refer to the COPYING.LIB document.        #
 #                                                                                      #
 ########################################################################################
 
@@ -58,7 +58,7 @@ class Config( object ):
     __metaclass__ = MetaSingleton
     
     def __init__(self):
-            self.__version = '1.0.7'
+            self.__version = '1.5.0'
             import Local.Config.Config
             import Local.Config.Execution
             #############################
@@ -208,7 +208,8 @@ class Config( object ):
             self._filelimit = 2147483648     #  2 Gib
             self._sessionlimit = 52428800    # 50 Mib
             self._previewDataLimit = 1048576 #  1 Mib
-            self._simultaneous_jobs = 1
+            self._max_similar_job_per_user = 1
+            self._max_job_per_user = 0
             
             self._result_remain = 10 # in day
             
@@ -223,12 +224,15 @@ class Config( object ):
             self._services_deployment_include = { 'programs' : [ '*' ] ,
                                                  'workflows' : [ '*' ] ,
                                                  'viewers'   : [ '*' ] ,
+                                                 'tutorials' : [ '*' ] ,
                                                  }
             self._services_deployment_exclude = { 'programs' : [] ,
                                                  'workflows' : [] ,
                                                  'viewers'   : [] ,
+                                                 'tutorials' : [] ,
                                                  }
-            
+            self._module_init = None
+            self._module_load= {}
             self._disable_all = False
             self._disabled_services = []
             
@@ -509,17 +513,43 @@ class Config( object ):
                 raise ConfigError , msg
             
             try:
-                self._simultaneous_jobs = int( Local.Config.Config.SIMULTANEOUS_JOBS )
-                if self._simultaneous_jobs < 0 :
-                    msg = "SIMULTANEOUS_JOBS have an invalid value : %s .\nIt must be a positive or null integer" % Local.Config.Config.SIMULTANEOUS_JOBS
+                self._max_similar_job_per_user = int( Local.Config.Config.MAX_SIMILAR_JOB_PER_USER )
+                if self._max_similar_job_per_user < 0 :
+                    msg = "MAX_SIMILAR_JOB_PER_USER have an invalid value : %s .\nIt must be a positive or null integer" % Local.Config.Config.MAX_SIMILAR_JOB_PER_USER
                     self.log.error( msg )
                     raise ConfigError , msg
             except AttributeError:
-                self.log.info( "SIMULTANEOUS_JOBS not found in  Local/Config/Config.py, set SIMULTANEOUS_JOBS to %d " %( self._simultaneous_jobs ))
+                try:
+                    self._max_similar_job_per_user = int( Local.Config.Config.SIMULTANEOUS_JOBS )
+                    if self._max_similar_job_per_user < 0 :
+                        msg = "SIMULTANEOUS_JOBS have an invalid value : %s .\nIt must be a positive or null integer" % Local.Config.Config.SIMULTANEOUS_JOBS
+                        self.log.error( msg )
+                        self.log.warning( "SIMULTANEOUS_JOBS has been replaced by MAX_SIMILAR_JOB_PER_USER please update you config (see UPDATE file)")
+                        raise ConfigError , msg
+                except AttributeError:
+                    self.log.info( "MAX_SIMILAR_JOB_PER_USER not found in  Local/Config/Config.py, set MAX_SIMILAR_JOB_PER_USER to %d " %( self._max_similar_job_per_user ))
+                except ValueError:
+                    msg = "SIMULTANEOUS_JOBS have an invalid value : %s .\nIt must be a positive or null integer" % Local.Config.Config.SIMULTANEOUS_JOBS
+                    self.log.error( msg )
+                    raise ConfigError , msg     
             except ValueError:
-                msg = "SIMULTANEOUS_JOBS have an invalid value : %s .\nIt must be a positive or null integer" % Local.Config.Config.SIMULTANEOUS_JOBS
+                msg = "MAX_SIMILAR_JOB_PER_USER have an invalid value : %s .\nIt must be a positive or null integer" % Local.Config.Config.MAX_SIMILAR_JOB_PER_USER
                 self.log.error( msg )
                 raise ConfigError , msg   
+            
+            
+            try:
+                self._max_job_per_user = int( Local.Config.Config.MAX_JOB_PER_USER )
+                if self._max_job_per_user < 0 :
+                    msg = "MAX_JOB_PER_USER have an invalid value : %s .\nIt must be a positive or null integer" % Local.Config.Config.MAX_JOB_PER_USER
+                    self.log.error( msg )
+                    raise ConfigError , msg
+            except AttributeError:
+                self.log.info( "MAX_JOB_PER_USER not found in  Local/Config/Config.py, users can submit as many jobs as they wants")
+            except ValueError:
+                msg = "MAX_JOB_PER_USER have an invalid value : %s .\nIt must be a positive or null integer" % Local.Config.Config.MAX_JOB_PER_USER
+                self.log.error( msg )
+                raise ConfigError , msg  
             #############################
             #
             #       CONVERTER
@@ -591,11 +621,27 @@ class Config( object ):
             except AttributeError:
                 self.log.info( "PARTICULAR_Q not found in  Local/Config/Config.py" )
 
-#            try:
-#                self._Qproperties = Local.Config.Config.Q_PROPERTIES
-#            except AttributeError:
-#                self.log.info( "Q_PROPERTIES not found in  Local/Config/Config.py" )
 
+            try:
+                self._module_init = Local.Config.Config.MODULE_INIT.strip()
+            except AttributeError:
+                self.log.info( "MODULE_INIT not found in  Local/Config/Config.py" )
+            
+            try:
+                self._module_load = Local.Config.Config.MODULE_LOAD
+            except AttributeError:
+                self.log.info( "MODULE_LOAD not found in  Local/Config/Config.py" )
+                
+            if self._module_load and not self._module_init:
+                msg = "MODULE_LOAD is specified Local/Config/Config.py but not MODULE_INIT"
+                self.log.error(msg)
+                raise ConfigError( msg )
+            elif self._module_init: 
+                self._module_init = os.path.abspath(os.path.realpath( self._module_init ))
+                if not os.path.exists(self._module_init):
+                    msg = "MODULE_INIT= %s: No such file" % self._module_init
+                    self.log.error(msg)
+                    raise ConfigError( msg )
             ##########################
             #
             # services publication
@@ -1002,13 +1048,20 @@ class Config( object ):
         """
         return self._result_remain
 
-    def simultaneous_jobs( self ):
+    def max_similar_job_per_user( self ):
         """
         @return: how many "indentical" jobs are allowed to be submit in same time.
         "indentical" jobs means same email, same IP, same commandline.
-        @rtype: int
+        @rtype: int (>=0)
         """
-        return self._simultaneous_jobs
+        return self._max_similar_job_per_user
+    
+    def max_job_per_user(self):
+        """
+        @return: how many jobs are allowed to be submit in same time.
+        @rtype: int (>=0)
+        """
+        return self._max_job_per_user
        
      
     def lang( self ):
@@ -1100,7 +1153,29 @@ class Config( object ):
         @rtype: a L{Dispatcher} instance
         """
         return self._dispatcher
+    
+    def module(self, serviceName ):
+        """
+        @param serviceName: the name of the service
+        @type serviceName: string
+        @return: the path to module init, and the module load to do if module is used or None otherwise
+        @rtype: tuple (string module_init_path , string  module load) or None
+        """
+        if not self._module_init:
+            return None
         
+        if serviceName in self._module_load:
+            module_load = self._module_load.get(serviceName)
+        elif 'DEFAULT' in self._module_load:
+            module_load = self._module_load['DEFAULT']
+        else:
+            #module_load is not define ifor this interface and there is no default
+            #don't use module load
+            module_load = None
+        if module_load is not None:
+            return (self._module_init, module_load)
+        else:
+            return None
         
     def accounting( self ):
         """
@@ -1111,8 +1186,9 @@ class Config( object ):
 
     def session_debug( self ):
         """
-        @return: True if the debug log on session is on, False otherwise.
-        @rtype: boolean
+        @return: the debug level for the session specifique logger. 
+        if there is no level specify in Config, return None 
+        @rtype: int
         """
         return self._session_debug
     
@@ -1232,7 +1308,7 @@ class Config( object ):
         @rtype: String
         """
         return self._portal_name
-
+    
     def simple_forms_active( self ):
         """
         @return: tells if "simple forms" should be displayed by default
@@ -1309,3 +1385,4 @@ class Config( object ):
         @rtype: string containing an HTML chunk
         """
         return self._custom_portal_footer
+    
