@@ -20,6 +20,7 @@ from Mobyle.Utils import safeFileName , sizeFormat
 from Mobyle.JobState import JobState , path2url , url2path
 from Mobyle.MobyleError import MobyleError , UserValueError , SessionError , NoSpaceLeftError 
 from Mobyle.JobFacade import JobFacade
+from Mobyle.BMPSWorkflow import BMPSWorkflow
 from Mobyle.Registry import registry
 
 from Mobyle.Transaction import Transaction
@@ -391,6 +392,21 @@ class Session( object ):
         transaction.commit()
         return workflows  
 
+    def getBMPSWorkflows(self):
+        """
+        get the list of workflow definitions in the session.
+        FIXME: replace with getWorkflows
+        @return: workflow definition identifiers list
+        @rtype: [ {'id':string } , ... 
+        """
+        session_workflow_path_list = glob.glob(os.path.join(self.getDir(), 'BMW', '*_mobyle.xml'))
+        session_workflow_list = {}
+        for p in session_workflow_path_list:
+            w = BMPSWorkflow.get_from_mobylexml_filepath(p, self)
+            session_workflow_list[w.pid] = {'id':w.name}
+        #session_workflow_list = dict((os.path.basename( p[:-11] ),{'id':os.path.basename( p[:-11] )}) for p in session_workflow_path_list)
+        return session_workflow_list
+
     def saveWorkflow(self, workflow):
         """
         save a new workflow version
@@ -421,7 +437,7 @@ class Session( object ):
         """
         return self.url+'/workflow%s.xml' % ID
 
-    def _createNewData(self , safeUserName , content , dataID , producer , nameInProducer , mobyleType , dataBegining , usedBy = None , producedBy = None ,  inputModes = None ):
+    def _createNewData(self, safeUserName, content, dataID, producer, nameInProducer, mobyleType, dataBegining, usedBy = None, producedBy = None,  inputModes = None ):
         """
         @param safeUserName: the user name for this  data
         @type safeUserName: string
@@ -530,7 +546,7 @@ class Session( object ):
         for f in os.listdir( self.Dir ):
             sessionSize += os.path.getsize( os.path.join( self.Dir  , f ) )
             if sessionSize > self.sessionLimit:  
-                self.log.debug( "%f : %s : _checkSpaceLeft call by= %s sizefound = %d" %( time() ,
+                self.log.debug( "%f : %s : _checkSpaceLeft call by= %s size found = %d" %( time() ,
                                                                                        self.getKey()  , 
                                                                                        os.path.basename( sys.argv[0] ) ,
                                                                                        sessionSize
@@ -763,6 +779,83 @@ class Session( object ):
             return s[ -3  ]
         else:
             return s[ -2 ]
+
+
+    def getAllUniqueLabels( self):
+        """
+        set description for the jobId
+        """
+        transaction= self._getTransaction(Transaction.READ)
+        
+        labelsList = transaction.getAllUniqueLabels()
+        transaction.commit()
+        return labelsList
+
+    def getJobLabels( self, jobID ):
+        """
+        @return: the labels for job with identifier jobID
+        @rtype: list of strings , [ string label1 ,string label2 ,...] or None if this jobs has no labels. 
+        @param jobID: the job identifier (it's url) of a job
+        @type jobID: string
+        @raise ValueError: if there is no job with jobID in the session
+        """
+        transaction= self._getTransaction(Transaction.READ)
+        labels = transaction.getJobLabels( jobID )
+        transaction.commit()
+        return labels
+    
+    def setJobLabels( self, jobID, inputLabels):
+        """
+        set labels for job with  jobId
+        @param jobID: the job identifier (it's url) of a job
+        @type jobID: string
+        @param description: the description of this job
+        @type description: string
+        @raise ValueError: if there is no job with jobID in the session
+        """
+        transaction= self._getTransaction(Transaction.WRITE)
+        transaction.setJobLabels( jobID, inputLabels)
+        transaction.commit()
+
+
+    def setJobDescription( self, jobID, description):
+        """
+        set description for the job with jobId
+        @param jobID: the job identifier (it's url) of a job
+        @type jobID: string
+        @param description: the description of this job
+        @type description: string
+        @raise ValueError: if there is no job with jobID in the session
+        """
+        transaction= self._getTransaction(Transaction.WRITE)
+        transaction.setJobDescription( jobID, description )
+        transaction.commit()
+
+    def getJobDescription( self, jobID):
+        """
+        @return: the description for job with identifier jobID
+        @rtype: string or None if there is no description for this job 
+        @param jobID: the job identifier (it's url) of a job
+        @type jobID: string
+        @raise ValueError: if there is no job with jobID in the session
+        """
+        transaction= self._getTransaction(Transaction.READ)
+        desc = transaction.getJobDescription( jobID )
+        transaction.commit()
+        return desc
+      
+    def getJobUserName( self, jobID):
+        """
+        @return: the user name for job with identifier jobID
+        @rtype: string or None if there is no user name for this job 
+        @param jobID: the job identifier (it's url) of a job
+        @type jobID: string
+        @raise ValueError: if there is no job with jobID in the session
+        """
+        transaction= self._getTransaction(Transaction.READ)
+        user_name = transaction.getJobUserName( jobID )
+        transaction.commit()
+        return user_name
       
 
     def hasJob(self , jobID ):
@@ -835,6 +928,15 @@ class Session( object ):
                     continue
             transaction.commit()
         return results
+
+    def getJobBMPS(self,jobID):
+        jobs=self.getAllJobs()
+        flattened_jobs = []
+        for j in jobs:
+            flattened_jobs.append(j)
+            flattened_jobs.extend(j['subjobs'])
+        j = [j for j in flattened_jobs if j['jobID']==jobID].pop()
+        return j
     
     
     def getJob(self , jobID ):
