@@ -37,31 +37,43 @@ def layout(workflow, program='dot', format='svg'):
                 link.from_parameter=p.prompt.replace('\n','').strip()
                 parameters.remove(p)
     for task in workflow.tasks:
-        inputs = '|'.join(list(set(['<%s>%s' % (link.to_parameter,link.to_parameter) for link in workflow.links if link.to_task==task.id])))
-        outputs = '|'.join(list(set(['<%s>%s' % (link.from_parameter,link.from_parameter) for link in workflow.links if link.from_task==task.id])))
-        label = "%(service)s|{{%(inputs)s}|%(description)s|{%(outputs)s}}" % {'service':task.service, 'description':task.description.replace('\n','').strip(), 'inputs':inputs,'outputs':outputs}
-        g.add_node(task,label=label,shape='record',tooltip=task.description)
+        #inputs = '|'.join(list(set(['<%s>%s' % (link.to_parameter,link.to_parameter) for link in workflow.links if link.to_task==task.id])))
+        #outputs = '|'.join(list(set(['<%s>%s' % (link.from_parameter,link.from_parameter) for link in workflow.links if link.from_task==task.id])))
+        #label = "%(service)s|{{%(inputs)s}|%(description)s|{%(outputs)s}}" % {'service':task.service, 'description':task.description.replace('\n','').strip(), 'inputs':inputs,'outputs':outputs}
+        #g.add_node(task,label=label,shape='record',tooltip=task.description)
+        d = task.description.replace('\n','').strip()
+        s = task.service.replace('\n','').strip()
+        if d is not None and d!='':
+            label = '%s (%s)' % (d,s)
+        else:
+            label = '%s' % s
+        g.add_node(task,label=label,shape='box',tooltip=task.description)
     for param in parameters:
-        g.add_node(param, label=param.prompt.replace('\n','').strip(), shape='diamond')
+        g.add_node(param, label=param.prompt.replace('\n','').strip(), shape='oval')
     for link in links:
-        sp, tp = None, None
+#        sp, tp = None, None
         if link.from_task:
             s = [s for s in workflow.tasks if s.id==link.from_task][0]
-            sp = link.from_parameter
+#            sp = link.from_parameter
         else:
             s = [s for s in workflow.parameters if s.id==link.from_parameter][0]
         if link.to_task:
             t = [t for t in workflow.tasks if t.id==link.to_task][0]
-            tp = link.to_parameter
+#            tp = link.to_parameter
         else:
             t = [t for t in workflow.parameters if t.id==link.to_parameter][0]
-        if sp and tp:
-            g.add_edge(g.get_node(s),g.get_node(t), headport=tp, tailport=sp)
-        elif sp:
-            g.add_edge(g.get_node(s),g.get_node(t), tailport=sp)            
-        elif tp:
-            g.add_edge(g.get_node(s),g.get_node(t), headport=tp)            
-        else:
+#        if sp and tp:
+#            g.add_edge(g.get_node(s),g.get_node(t), headport=tp, tailport=sp)
+#        elif sp:
+#            g.add_edge(g.get_node(s),g.get_node(t), tailport=sp)            
+#        elif tp:
+#            g.add_edge(g.get_node(s),g.get_node(t), headport=tp)            
+#        else:
+#            g.add_edge(g.get_node(s),g.get_node(t))
+        if not(g.has_edge(g.get_node(s),g.get_node(t))):
             g.add_edge(g.get_node(s),g.get_node(t))
+    #log.error(g.to_string())
     g.layout(prog=program)
+    #log.error(g.to_string())
+    #log.error(g.draw(format=format))
     return g.draw(format=format)
\ No newline at end of file
